Index: include/core/SkWeakRefCnt.h |
=================================================================== |
--- include/core/SkWeakRefCnt.h (revision 12696) |
+++ include/core/SkWeakRefCnt.h (working copy) |
@@ -89,9 +89,9 @@ |
*/ |
bool SK_WARN_UNUSED_RESULT try_ref() const { |
if (sk_atomic_conditional_inc(&fRefCnt) != 0) { |
// Aquire barrier (L/SL), if not provided above. |
// Prevents subsequent code from happening before the increment. |
- sk_membar_aquire__after_atomic_conditional_inc(); |
+ sk_membar_acquire__after_atomic_conditional_inc(); |
return true; |
} |
return false; |
@@ -115,9 +115,9 @@ |
SkASSERT(fWeakCnt > 0); |
// Release barrier (SL/S), if not provided below. |
if (sk_atomic_dec(&fWeakCnt) == 1) { |
// Aquire barrier (L/SL), if not provided above. |
// Prevents code in destructor from happening before the decrement. |
- sk_membar_aquire__after_atomic_dec(); |
+ sk_membar_acquire__after_atomic_dec(); |
#ifdef SK_DEBUG |
// so our destructor won't complain |
fWeakCnt = 1; |
@@ -89,9 +89,9 @@ |
bool SK_WARN_UNUSED_RESULT try_ref() const { |
if (sk_atomic_conditional_inc(&fRefCnt) != 0) { |
- // Aquire barrier (L/SL), if not provided above. |
+ // Acquire barrier (L/SL), if not provided above. |
// Prevents subsequent code from happening before the increment. |
@@ -115,9 +115,9 @@ |
// Release barrier (SL/S), if not provided below. |
if (sk_atomic_dec(&fWeakCnt) == 1) { |
- // Aquire barrier (L/SL), if not provided above. |
+ // Acquire barrier (L/SL), if not provided above. |
// Prevents code in destructor from happening before the decrement. |